@@ -1,15 +1,13 @@
 // Copyright 2014 Canonical Ltd.
 // Licensed under the LGPLv3, see LICENCE file for details.
 
-package loggo_test
+package loggo
 
 import (
 	"bytes"
 	"time"
 
 	gc "gopkg.in/check.v1"
-
-	"github.com/juju/loggo"
 )
 
 type SimpleWriterSuite struct{}
@@ -18,14 +16,14 @@ var _ = gc.Suite(&SimpleWriterSuite{})
 
 func (s *SimpleWriterSuite) TestNewSimpleWriter(c *gc.C) {
 	now := time.Now()
-	formatter := func(entry loggo.Entry) string {
+	formatter := func(entry Entry) string {
 		return "<< " + entry.Message + " >>"
 	}
 	buf := &bytes.Buffer{}
 
-	writer := loggo.NewSimpleWriter(buf, formatter)
-	writer.Write(loggo.Entry{
-		Level:     loggo.INFO,
+	writer := NewSimpleWriter(buf, formatter)
+	writer.Write(Entry{
+		Level:     INFO,
 		Module:    "test",
 		Filename:  "somefile.go",
 		Line:      12,
@@ -39,20 +37,20 @@ func (s *SimpleWriterSuite) TestNewSimpleWriter(c *gc.C) {
 
 func (s *SimpleWriterSuite) TestNewSimpleWriterWithLabels(c *gc.C) {
 	now := time.Now()
-	formatter := func(entry loggo.Entry) string {
+	formatter := func(entry Entry) string {
 		return "<< " + entry.Message + " >>"
 	}
 	buf := &bytes.Buffer{}
 
-	writer := loggo.NewSimpleWriter(buf, formatter)
-	writer.Write(loggo.Entry{
-		Level:     loggo.INFO,
+	writer := NewSimpleWriter(buf, formatter)
+	writer.Write(Entry{
+		Level:     INFO,
 		Module:    "test",
 		Filename:  "somefile.go",
 		Line:      12,
 		Timestamp: now,
 		Message:   "a message",
-		Labels:    []string{"ONE", "TWO"},
+		Labels:    Labels{LoggerTags: "ONE,TWO"},
 	})
 
 	c.Check(buf.String(), gc.Equals, "<< a message >>\n")
